package br.usp.poli.java;

/**
 * Representao de um jogador para o jogo de poquer.<br />
 * O jogador deve ser intercambivel, ou seja, independente da implementao
 * de jogo de pquer deve ser possvel usar uma implementao de Jogador.<br />
 * 
 * @author FLevy
 * @version 1.1 - O mtodo avisarGanhouMao avisa se houve empate.
 */
public interface Jogador {

	/**
	 * Obtm o nome deste jogador.
	 * 
	 * @return O nome deste jogador.
	 */
	public String getNome();

	/**
	 * Avisa que o jogador teve que fazer um depsito para iniciar a mo.
	 * 
	 * @param deposito
	 *            O nmero de fichas necessrio para o depsito nesta mo.
	 * @param fichasDisponiveis
	 *            O nmero de fichas que este jogador tem disponvel (sem
	 *            considerar o depsito).
	 */
	public void avisarDeposito(int deposito, int fichasDisponiveis);

	/**
	 * Recebe as cartas que sero usadas.
	 * 
	 * @param mao
	 *            A mo, que dependendo do jogo pode ter 5 ou 3 cartas.
	 */
	public void receberCartas(Carta[] mao);

	/**
	 * Pergunta ao jogador se ele quer passar (se possvel), sair ou apostar
	 * nesta rodada de apostas.
	 * 
	 * @param fichasDisponiveis
	 *            O nmero de fichas que este jogador tem disponvel.
	 * @param valorDaApostaMinima
	 *            O valor mnimo de aposta.
	 * @param pote
	 *            O valor do pote atual.
	 * @return -1 se o jogador for sair, 0 se ele passar, ou > 0 caso ele
	 *         aumentar.
	 */
	public int apostar(int fichasDisponiveis, int valorDaApostaMinima, int pote);

	/**
	 * Pergunta ao jogador se ele deseja cobrir uma aposta ou no.
	 * 
	 * @param fichasDisponiveis
	 *            O nmero de fichas que este jogador tem disponvel.
	 * @param fichasNecessariasParaCobrir
	 *            O nmero de fichas para cobrir.
	 * @param pote
	 *            O valor do pote atual.
	 * @return Se o jogador cobre (true) ou sai (false)
	 */
	public boolean cobrir(int fichasDisponiveis,
			int fichasNecessariasParaCobrir, int pote);
	
	/**
	 * Mostra as cartas que o jogador tem.
	 * 
	 * @return Mostra as cartas que o jogador tem.
	 */
	public Carta[] mostrar();

	/**
	 * Avisa o fim de uma mo, informando se o jogador ganhou ou perdeu.
	 * 
	 * @param resultado
	 *            Se o jogador ganhou (resultado > 0), perdeu (resultado < 0) ou
	 *            empatou (resultado == 0).
	 * @param pote
	 *            O pote que estava em jogo.
	 * @param fichasDisponiveis
	 *            O nmero de fichas que ele tem disponvel, considerando o pote
	 *            (caso ele ganhou).
	 */
	public void avisarGanhouMao(int resultado, int pote, int fichasDisponiveis);
}
